local L = LibStub("AceLocale-3.0"):GetLocale("AspectInspect")
local media = LibStub:GetLibrary("LibSharedMedia-3.0");

AspectInspect.fonteffects = {
	["none"] = L["none"],
	["OUTLINE"] = L["OUTLINE"],
	["THICKOUTLINE"] = L["THICKOUTLINE"],
	["MONOCHROME"] = L["MONOCHROME"],
}

function AspectInspect:GetOptions()
	local options = { 
		name = "AspectInspect",
		handler = AspectInspect,
		type='group',
		childGroups ='tree',
		args = {
			debug = {
				type = 'toggle',
				name = L["Debug mode"],
				desc = L["help_debug"],
				get = "getDebug",
				set = "setDebug",
				order = 1,
			},
			config = {
				type = 'execute',
				name = L["Configure Options"],
				desc = L["help_config"],
				func = "OpenConfig",
				guiHidden = true,
				order = 2,
			},
			version = {
				type = 'execute',
				name = L["Version"],
				desc = L["help_version"],
				func = "DisplayVersion",
				order = 3,
			},
			help = {
				type = 'description',
				name = L["help"],
				guiHidden = true,
				order = 4,
			},
			hideooc= {
				type = 'toggle',
				name = L["Hide out of combat"],
				desc = L["help_hideooc"],
				get = "getHideooc",
				set = "setHideooc",
				order = 5,
			},
			colours = {
				name = L["Colour Options"],
				type = 'group',
				order = 6,
				args = {
					hawk = {
						type = 'color',
						name = L["Aspect of Hawk Colour"],
						desc = L["colAspectHawk"],
						get = "getAspectHawkColour",
						set = "setAspectHawkColour",
						hasAlpha = true,
						order = 1,
					},
				},
			},
		},
	}
	return options
end

function AspectInspect:getDebug()
	return self.db.char.debug
end

function AspectInspect:setDebug()
	self.db.char.debug = not self.db.char.debug
	if (self.db.char.debug) then
		self:Print(L["config_debug_on"])
	else
		self:Print(L["config_debug_off"])
	end
end

function AspectInspect:getHideooc()
	return self.db.char.hideooc
end

function AspectInspect:setHideooc()
	self.db.char.hideooc = not self.db.char.hideooc
	if (self.db.char.hideooc) then
		self:Print(L["config_hideooc_on"])
	else
		self:Print(L["config_hideooc_off"])
	end
end

function AspectInspect:FinishedMoving(var, frame)
	local point, relativeTo, relativePoint, xOffset, yOffset = frame:GetPoint();
	var.point = point
	var.relativeTo = relativeTo
	var.relativePoint = relativePoint
	var.xOffset = xOffset
	var.yOffset = yOffset
end

function AspectInspect:GetWidth()
    return self.db.char.fWidth
end

function AspectInspect:GetScale()
    return self.db.char.scale
end

function AspectInspect:SetScale(info,newValue)
	self.db.char.scale = newValue
	self.BagFrame:SetScale(self.db.char.scale)
	self:Print("Scale set to : "..self.db.char.scale)
end

function AspectInspect:OpenConfig()
	  if InterfaceOptionsFrame_OpenToCategory then
	    InterfaceOptionsFrame_OpenToCategory("AspectInspect");
    else
        InterfaceOptionsFrame_OpenToFrame("AspectInspect");
    end
end

function AspectInspect:DisplayVersion()
	self:Print(self.version)
end

function AspectInspect:getAspectHawkColour(info)
	local colours = self.db.char.colours.aspecthawk
	return colours.r, colours.g, colours.b, colours.a
end

function AspectInspect:setAspectHawkColour(info,r,g,b,a)
	self.db.char.colours.aspecthawk.r = r
	self.db.char.colours.aspecthawk.g = g
	self.db.char.colours.aspecthawk.b = b
	self.db.char.colours.aspecthawk.a = a
end
